@@ -1,5 +1,5 @@
 package DBIx::Lite::Row;
-$DBIx::Lite::Row::VERSION = '0.26';
+$DBIx::Lite::Row::VERSION = '0.27';
 use strict;
 use warnings;
 
@@ -126,7 +126,7 @@ DBIx::Lite::Row
 
 =head1 VERSION
 
-version 0.26
+version 0.27
 
 =head1 OVERVIEW
 
@@ -135,7 +135,9 @@ first Result objects by calling one of retrieval methods on a L<DBIx::Lite::Resu
 object.
 
 Accessor methods will be provided automatically for all retrieved columns and for 
-related tables (see docs for L<DBIx::Lite::Schema>).
+related tables (see docs for L<DBIx::Lite::Schema>). If a column does not exist, 
+calling its method will die with an exception (use L<get> if you want to handle 
+this gracefully).
 
     my $book = $dbix->table('books')->find({ id => 10 });
     print $book->title;
@@ -148,6 +150,13 @@ This method returns a hashref containing column values.
     my $hashref = $book->hashref;
     print "$_ = $hashref->{$_}\n" for keys %$hashref;
 
+=head2 get
+
+This method accepts a column names and returns its value. If the column does not 
+exist, it returns undef.
+
+    print $book->get('title');
+
 =head2 update
 
 This method is only available if you specified a primary key for the table
